#
# spec file for package e-antic
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libeantic1
Name:           e-antic
Version:        1.0.3
Release:        bp154.1.46
Summary:        Real Embedded Algebraic Number Theory in C
License:        LGPL-2.1-or-later AND LGPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://github.com/flatsurf/e-antic

Source:         https://github.com/flatsurf/e-antic/releases/download/%version/e-antic-%version.tar.gz
BuildRequires:  antic-devel
BuildRequires:  arb-devel
BuildRequires:  automake
BuildRequires:  cereal-devel
BuildRequires:  fdupes
BuildRequires:  flint-devel >= 2.6
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  libtool
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
BuildRequires:  unique-factory-devel
BuildRequires:  pkgconfig(catch2)

%description
E-ANTIC is a C/C++ library to deal with real embedded number fields
built on top of ANTIC.

%package -n %lname
Summary:        Real Embedded Algebraic Number Theory library in C
Group:          System/Libraries

%description -n %lname
E-ANTIC is a C/C++ library to deal with real embedded number fields
built on top of ANTIC.

%package devel
Summary:        Development files for e-antic
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       antic-devel
Requires:       arb-devel
Requires:       libboost_headers-devel

%description devel
E-ANTIC is a C/C++ library to deal with real embedded number fields
built on top of ANTIC.

This subpackage contains the include files and library links for
developing against the ANTIC library.

%package -n python3-pyeantic
Summary:        Python interface for e-antic
Group:          Development/Languages/Python

%description -n python3-pyeantic
pyeantic is a Python interface on top of E-ANTIC, itself a
a C/C++ library for real embedded number fields atop ANTIC.

%prep
%autosetup -p1

%build
autoreconf -fi
%configure --disable-static --without-benchmark --without-byexample \
	--without-pytest --without-doc
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la
find "%buildroot" -name install_files.txt -delete
%fdupes %buildroot/%_prefix

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPY*
%_libdir/libeantic*.so.1*

%files -n python3-pyeantic
%python3_sitelib/pyeantic*/

%files devel
%_includedir/e-antic/
%_includedir/libeantic/
%_libdir/libeantic*.so

%changelog
* Sun Aug 15 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.3
  * Fixed linking of C++ test programs.
* Fri Aug  6 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.2
  * Fixed parsing of trivial number fields in pyeantic.
  * Conversion from NumberField to RealEmbeddedNumberField when
    the defining polynomial is not in x.
* Fri Jul  2 2021 Jan Engelhardt <jengelh@inai.de>
- Add Requires to e-antic-devel so that all headers can be used.
* Fri Jun 25 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.1
  * Allow creation of RealEmbeddedNumberField from an intrusive
    pointer in pyeantic.
* Fri Jun 18 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.0
  * Added Python wrapper
  * Added renf_elem_class::floordiv() to perform (a/b).floor()
    more efficiently
  * The C++ interface now requires C++14.
* Tue Sep 22 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 1.0.0~rc1) for build.opensuse.org
